@@ -18,6 +18,11 @@
 #ifndef __FUT_H__
 #define __FUT_H__
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 /*	fut = Fast User Tracing */
 
 #ifdef MARCEL
@@ -389,4 +394,8 @@ extern void fut_disable_tid_logging();
 #endif
 
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
