@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2011, 2013, 2017 Samuel Thibault <samuel.thibault@ens-lyon.org>
+ *  Copyright (C) 2004, 2011, 2013, 2017-2018 Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,12 @@
 
 #ifndef __FXT_H
 #define __FXT_H
+
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 #include <stdio.h>
 #include <time.h>
 #include <sys/types.h>
@@ -85,6 +91,7 @@ struct fxt_infos {
 #define FXT_ARCH_MIPSEL 6
 #define FXT_ARCH_SH 7
 #define FXT_ARCH_PPC64EL 8
+#define FXT_ARCH_RISCV64 9
 #define FXT_ARCH_UNKNOWN_EL 255
 
 /* Big-endian machines */
@@ -398,6 +405,9 @@ struct fxt_trace_user_raw64 {
 #elif defined(__sh__)
 #  define FXT_RECORD_ARCH FXT_ARCH_SH
 
+#elif defined(__riscv) && (__riscv_xlen==64)
+#  define FXT_RECORD_ARCH FXT_ARCH_RISCV64
+
 #else
 #  if defined(__LITTLE_ENDIAN__)
 #    define FXT_RECORD_ARCH FXT_ARCH_UNKNOWN_EL
@@ -431,4 +441,8 @@ typedef struct fxt_trace_kernel_raw32 fxt_trace_kernel_raw_t;
 typedef struct fxt_trace_user_raw64 fxt_trace_user_raw_t;
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __FXT_H */
