@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003, 2004, 2011-2012, 2016  Samuel Thibault <samuel.thibault@ens-lyon.org>
+ *  Copyright (C) 2003, 2004, 2011-2012, 2016-2017  Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,7 +77,10 @@ static int recordrunningpid( char *statfilename, char pidname[FXT_MAXCOMMLEN+2+1
 
 	if( !(file = fopen(statfilename,"r")) )
 		return 0; /* may happen if it just died */
-	res = fscanf(file,"%*d %s",pidname);
+#if (FXT_MAXCOMMLEN+2+1) != 17+1
+#error update format here:
+#endif
+	res = fscanf(file,"%*d %17s",pidname);
 	fclose(file);
 	return res==1;
 	}
