@@ -65,7 +65,7 @@ int main(void) {
 	FUT_PROBE7(0x1, 0x107, 1234, 1234, 1234, 1234, 1234, 1234, 1234);
 
 	fprintf(stderr,"running string probe\n");
-	FUT_PROBESTR(0x1, 0x200, "foo");
+	FUT_PROBESTR(0x1, 0x200, "foof");
 	fprintf(stderr,"ending up\n");
 	if (fut_endup("temp2") < 0)
 	{
@@ -80,11 +80,17 @@ int main(void) {
 	}
 	fprintf(stderr,"ok\n");
 	if (system("./fxt_print -f temp2 > fxt_print.log") != 0) {
-		fprintf(stderr,"erreur fxt_print");
+		fprintf(stderr,"error fxt_print");
 		exit(EXIT_FAILURE);
 	}
-	if (system("grep \"4294967295	             200(1)	         unknown code 200	6f6f66\" fxt_print.log") != 0) {
-		fprintf(stderr,"erreur sortie de fxt_print");
+	if (system("grep \"4294967295	             107(7)	         unknown code 107	4d2	4d2	4d2	4d2	4d2	4d2	4d2\" fxt_print.log") != 0) {
+		system("cat fxt_print.log");
+		fprintf(stderr,"error fxt_print string output");
+		exit(EXIT_FAILURE);
+	}
+	if (system("grep \"4294967295	             200(1)	         unknown code 200	666f6f66\" fxt_print.log") != 0) {
+		system("cat fxt_print.log");
+		fprintf(stderr,"error fxt_print string output");
 		exit(EXIT_FAILURE);
 	}
 	exit(EXIT_SUCCESS);
